@@ -1,12 +1,13 @@
 package LWP::UserAgent::ProgressAny;
 
 our $DATE = '2015-01-22'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
+use Number::Format::Metric qw(format_metric);
 use Progress::Any;
 use Scalar::Util qw(refaddr);
 
@@ -37,9 +38,22 @@ sub __add_handlers {
                 $progress->target($cl);
             }
         }
+        my $new_pos = $progress->pos() + length($data);
         $progress->update(
-            pos => $progress->pos() + length($data),
-            message => "Downloading " . $resp->{_request}{_uri},
+            pos => $new_pos,
+            message => sub {
+                my @msg = (
+                    "Downloading ",
+                    $resp->{_request}{_uri},
+                    " ",
+                    format_metric($new_pos),
+                );
+                if ($progress->target) {
+                    push @msg, "/", format_metric($progress->target);
+                }
+                # XXX show speed
+                join "", @msg;
+            },
         );
 
         # so we are called again for the next chunk
@@ -86,7 +100,7 @@ LWP::UserAgent::ProgressAny - See progress for your LWP::UserAgent requests
 
 =head1 VERSION
 
-This document describes version 0.02 of LWP::UserAgent::ProgressAny (from Perl distribution LWP-UserAgent-ProgressAny), released on 2015-01-22.
+This document describes version 0.03 of LWP::UserAgent::ProgressAny (from Perl distribution LWP-UserAgent-ProgressAny), released on 2015-01-22.
 
 =head1 SYNOPSIS
 
